@@ -45,7 +45,7 @@ pub fn find(id: &str) -> Result<Game> {
     if library_manifests.is_none() {
         return Err(Error::new(
             ErrorKind::GameNotFound,
-            format!("Steam game with id {} does not exist", id),
+            format!("Steam game with id ({}) does not exist", id),
         ));
     }
 
