@@ -1,6 +1,7 @@
-use std::path::PathBuf;
+use std::path::{Path, PathBuf};
 
 use crate::error::{Error, ErrorKind, Result};
+use crate::prelude::{Game, GameCommands, GameState, GameType};
 use crate::util::path::fix_path_separator;
 use crate::util::registry;
 
@@ -60,8 +61,8 @@ pub fn get_manifest_ids() -> Result<Vec<String>> {
     return manifests;
 }
 
-pub fn get_game_info(manifest_id: &String) -> Result<(String, String)> {
-    let manifest = registry::get_local_machine_reg_key(
+pub fn get_game_info(manifest_id: &String) -> Result<(String, PathBuf)> {
+    registry::get_local_machine_reg_key(
         format!(
             "Microsoft\\Windows\\CurrentVersion\\Uninstall\\Uplay Install {}",
             manifest_id
@@ -71,22 +72,50 @@ pub fn get_game_info(manifest_id: &String) -> Result<(String, String)> {
     .and_then(|game_reg| {
         registry::get_value(&game_reg, "DisplayName").and_then(|game_name| {
             registry::get_value(&game_reg, "InstallLocation")
-                .map(|value| fix_path_separator(value.as_ref()).display().to_string())
+                .map(|value| fix_path_separator(value.as_ref()))
                 .map(|game_path| (game_name, game_path))
         })
-    });
-
-    if manifest.is_err() {
-        return Err(Error::new(
+    })
+    .map_err(|error| {
+        Error::new(
             ErrorKind::InvalidGame,
-            format!(
-                "Error on read the Ubisoft manifest: {}",
-                manifest.err().unwrap().to_string()
-            ),
-        ));
-    }
+            format!("Error on read the Ubisoft manifest: {}", error.to_string()),
+        )
+    })
+}
 
-    let manifest = manifest.unwrap();
+pub fn parse_game_info(
+    id: &String,
+    game_info: &(String, PathBuf),
+    launcher_executable: &Path,
+) -> Game {
+    let (name, path) = game_info;
 
-    return Ok(manifest);
+    Game {
+        _type: GameType::Ubisoft.to_string(),
+        id: id.clone(),
+        name: name.clone(),
+        path: Some(path.clone()),
+        commands: GameCommands {
+            install: Some(vec![
+                launcher_executable.display().to_string(),
+                format!("uplay://install/{}", &id),
+            ]),
+            launch: Some(vec![
+                launcher_executable.display().to_string(),
+                format!("uplay://launch/{}/0", &id),
+            ]),
+            uninstall: Some(vec![
+                launcher_executable.display().to_string(),
+                format!("uplay://uninstall/{}", &id),
+            ]),
+        },
+        state: GameState {
+            installed: true,
+            needs_update: false,
+            downloading: false,
+            total_bytes: None,
+            received_bytes: None,
+        },
+    }
 }
